@@ -312,7 +312,7 @@ class TrackerJobsBase(abc.ABC):
     @cached_property
     def add_torrent_job(self):
         """:class:`~.jobs.torrent.AddTorrentJob` instance"""
-        if self.bittorrent_client:
+        if self.bittorrent_client and self.create_torrent_job:
             add_torrent_job = jobs.torrent.AddTorrentJob(
                 autostart=False,
                 client=self.bittorrent_client,
@@ -331,7 +331,7 @@ class TrackerJobsBase(abc.ABC):
     @cached_property
     def copy_torrent_job(self):
         """:class:`~.jobs.torrent.CopyTorrentJob` instance"""
-        if self.torrent_destination:
+        if self.torrent_destination and self.create_torrent_job:
             copy_torrent_job = jobs.torrent.CopyTorrentJob(
                 autostart=False,
                 destination=self.torrent_destination,
@@ -381,7 +381,7 @@ class TrackerJobsBase(abc.ABC):
     def _update_release_name(self, imdb_id):
         self.release_name_job.add_task(
             self.release_name_job.fetch_text(
-                coro=self.release_name.fetch_info(imdb_id),
+                coro=self.release_name.fetch_info(imdb_id=imdb_id),
                 error_is_fatal=False,
             ),
         )
@@ -450,7 +450,7 @@ class TrackerJobsBase(abc.ABC):
     @cached_property
     def upload_screenshots_job(self):
         """:class:`~.jobs.imghost.ImageHostJob` instance"""
-        if self.image_host:
+        if self.image_host and self.screenshots_job:
             imghost_job = jobs.imghost.ImageHostJob(
                 imghost=self.image_host,
                 **self.common_job_args,
