@@ -19,11 +19,22 @@ class BbTrackerConfig(TrackerConfigBase):
         'exclude'     : [
             r'\.(?i:nfo|txt|jpg|jpeg|png|sfv|md5)$',
             r'/(?i:sample|extra|bonus|feature)',
+            r'(?i:sample\.[a-z]+)$',
         ],
     }
 
     argument_definitions = {
         'submit': {
+            ('--anime', '--an'): {
+                'help': 'Tag upload as anime (ignored for movies)',
+                'action': 'store_true',
+            },
+            ('--description', '--de'): {
+                'help': 'Custom description as text or path to UTF-8 encoded text file',
+            },
+            ('--poster', '--po'): {
+                'help': 'Path or URL to poster image',
+            },
             ('--screenshots', '--ss'): {
                 'help': ('How many screenshots to make '
                          f'(min={defaults["screenshots"].min}, '
@@ -33,37 +44,33 @@ class BbTrackerConfig(TrackerConfigBase):
                     max=defaults['screenshots'].max,
                 ),
             },
-            ('--poster-file',): {
-                'help': 'Path or URL to poster image',
+            ('--tags', '--ta'): {
+                'help': 'Custom list of comma-separated tags',
             },
-            ('--anime', '--an'): {
-                'help': 'Tag upload as anime (ignored for movies)',
+            ('--only-description', '--od'): {
+                'help': 'Only generate description (do not upload anything)',
                 'action': 'store_true',
-            },
-            ('--description', '--desc'): {
                 'group': 'generate-metadata',
-                'help': 'Only generate description',
-                'action': 'store_true',
             },
-            ('--poster', '-p'): {
-                'group': 'generate-metadata',
-                'help': 'Only generate poster URL',
+            ('--only-poster', '--op'): {
+                'help': 'Only generate poster URL (do not upload anything)',
                 'action': 'store_true',
+                'group': 'generate-metadata',
             },
-            ('--release-info', '-i'): {
-                'group': 'generate-metadata',
-                'help': 'Only generate release info',
+            ('--only-release-info', '--or'): {
+                'help': 'Only generate release info (do not upload anything)',
                 'action': 'store_true',
+                'group': 'generate-metadata',
             },
-            ('--tags', '-g'): {
-                'group': 'generate-metadata',
-                'help': 'Only generate tags',
+            ('--only-tags', '--ota'): {
+                'help': 'Only generate tags (do not upload anything)',
                 'action': 'store_true',
+                'group': 'generate-metadata',
             },
-            ('--title', '-t'): {
-                'group': 'generate-metadata',
-                'help': 'Only generate title',
+            ('--only-title', '--oti'): {
+                'help': 'Only generate title (do not upload anything)',
                 'action': 'store_true',
+                'group': 'generate-metadata',
             },
         },
     }
