@@ -58,12 +58,6 @@ class BbTrackerJobs(TrackerJobsBase):
         if match:
             return int(match.group(1))
 
-    promotion = (
-        '[align=right][size=1]Shared with '
-        f'[url={__homepage__}]{__project_name__} {__version__}[/url]'
-        '[/size][/align]'
-    )
-
     # Web DBs
 
     async def get_imdb_id(self):
@@ -84,7 +78,7 @@ class BbTrackerJobs(TrackerJobsBase):
             if self.tvmaze_job.output:
                 return self.tvmaze_job.output[0]
 
-    async def try_webdbs(self, webdbs, method):
+    async def try_webdbs(self, webdbs, method, default=None):
         """
         Try to run `method` on each item in `webdbs` and return the first truthy
         return value
@@ -107,9 +101,13 @@ class BbTrackerJobs(TrackerJobsBase):
                 result = await result_getter(id)
                 if result:
                     return result
-        # Default to return value from final webdb, e.g. empty string, empty
-        # list, etc.
-        return result
+        try:
+            # Default to return value from final webdb, e.g. empty string, empty
+            # list, etc (these wouldn't be returned above, they are falsy)
+            return result
+        except NameError:
+            # Return default if we couldn't get an ID for any webdb
+            return default
 
     # Jobs
 
@@ -121,8 +119,8 @@ class BbTrackerJobs(TrackerJobsBase):
                                   'screenshots_job', 'upload_screenshots_job',
                                   'add_torrent_job', 'copy_torrent_job')
         for job_attr in generic_job_attributes:
-            job = getattr(self, job_attr, None)
-            if job:
+            job = getattr(self, job_attr)
+            if job is not None:
                 job.condition = self.make_job_condition(job_attr, *all_release_types)
 
         # Return all possible jobs and disable/enable them via JobBase's
@@ -167,15 +165,17 @@ class BbTrackerJobs(TrackerJobsBase):
         def condition():
             if self.release_type in release_types:
                 # Job is appropriate for release type
-                if not self.isolated_jobs:
+                isolated_jobs = self.isolated_jobs
+                if not isolated_jobs:
                     # No jobs where singled out via CLI arguments or other
                     # means; all appropriate jobs are enabled
                     return True
-                elif job_attr in self.isolated_jobs:
+                elif job_attr in isolated_jobs:
                     # This particular job was singled out by the user;
                     # all other jobs are disabled
                     return True
             return False
+
         return condition
 
     @property
@@ -185,27 +185,27 @@ class BbTrackerJobs(TrackerJobsBase):
         by the user, e.g. with a CLI argument
         """
         if self.is_movie_release:
-            if self.options.get('title', False):
-                return ('imdb_job', 'movie_title_job')
-            elif self.options.get('description', False):
+            if self.options.get('only_description', False):
                 return ('imdb_job', 'movie_description_job')
-            elif self.options.get('poster', False):
+            elif self.options.get('only_poster', False):
                 return ('imdb_job', 'movie_poster_job')
-            elif self.options.get('release_info', False):
+            elif self.options.get('only_release_info', False):
                 return ('movie_release_info_job',)
-            elif self.options.get('tags', False):
+            elif self.options.get('only_tags', False):
                 return ('imdb_job', 'movie_tags_job')
+            elif self.options.get('only_title', False):
+                return ('imdb_job', 'movie_title_job')
 
         elif self.is_series_release:
-            if self.options.get('title', False) or self.options.get('release_info', False):
-                # Series title and release_info are combined
-                return ('tvmaze_job', 'series_title_job')
-            elif self.options.get('description', False):
+            if self.options.get('only_description', False):
                 return ('tvmaze_job', 'mediainfo_job', 'screenshots_job',
                         'upload_screenshots_job', 'series_description_job')
-            elif self.options.get('poster', False):
+            elif self.options.get('only_poster', False):
                 return ('tvmaze_job', 'series_poster_job')
-            elif self.options.get('tags', False):
+            elif self.options.get('only_title', False) or self.options.get('only_release_info', False):
+                # Series title and release_info are combined
+                return ('tvmaze_job', 'series_title_job')
+            elif self.options.get('only_tags', False):
                 return ('tvmaze_job', 'series_tags_job')
 
         return ()
@@ -236,16 +236,14 @@ class BbTrackerJobs(TrackerJobsBase):
     @cached_property
     def imdb_job(self):
         """:class:`~.jobs.webdb.WebDbSearchJob` instance"""
-        return jobs.webdb.WebDbSearchJob(
-            condition=self.make_job_condition('imdb_job', release.ReleaseType.movie),
-            query=self.content_path,
-            db=self.imdb,
-            **self.common_job_args,
-        )
+        imdb_job = super().imdb_job
+        imdb_job.condition = self.make_job_condition('imdb_job', release.ReleaseType.movie)
+        imdb_job.no_id_ok = True
+        return imdb_job
 
     @cached_property
     def movie_title_job(self):
-        self.imdb_job.signal.register('output', self.fill_in_movie_title)
+        self.imdb_job.signal.register('finished', self.fill_in_movie_title)
         return jobs.dialog.TextFieldJob(
             name=self.get_job_name('movie-title'),
             label='Title',
@@ -257,30 +255,23 @@ class BbTrackerJobs(TrackerJobsBase):
     def movie_title_validator(self, text):
         text = text.strip()
         if not text:
-            raise ValueError(f'Invalid title: {text}')
+            raise ValueError('Failed to autodetect title')
 
-    def fill_in_movie_title(self, imdb_id):
-        default_text = self.release_name.title_with_aka
-        coro = self.get_movie_title(imdb_id)
+    def fill_in_movie_title(self, job_):
         task = self.movie_title_job.fetch_text(
-            coro=coro,
-            default_text=default_text,
+            coro=self.get_movie_title(),
+            default_text=self.release_name.title_with_aka,
             finish_on_success=False,
         )
         self.movie_title_job.add_task(task)
 
     @cached_property
     def movie_year_job(self):
-        self.imdb_job.signal.register('output', self.fill_in_movie_year)
-        if self.release_name.year == 'UNKNOWN_YEAR':
-            guessed_year = ''
-        else:
-            guessed_year = self.release_name.year
+        self.imdb_job.signal.register('finished', self.fill_in_movie_year)
         return jobs.dialog.TextFieldJob(
             name=self.get_job_name('movie-year'),
             label='Year',
             condition=self.make_job_condition('movie_year_job', release.ReleaseType.movie),
-            text=guessed_year,
             validator=self.movie_year_validator,
             **self.common_job_args,
         )
@@ -290,12 +281,12 @@ class BbTrackerJobs(TrackerJobsBase):
         self.release_name.year = text
         # release_name.year is now "UNKNOWN_YEAR" if year is required but not known
         if self.release_name.year == 'UNKNOWN_YEAR':
-            raise ValueError('Failed to autodetect year.')
+            raise ValueError('Failed to autodetect year')
 
-    def fill_in_movie_year(self, imdb_id):
-        coro = self.imdb.year(imdb_id)
+    def fill_in_movie_year(self, job_):
         task = self.movie_year_job.fetch_text(
-            coro=coro,
+            coro=self.get_movie_year(),
+            default_text=self.release_name.year,
             finish_on_success=True,
         )
         self.movie_year_job.add_task(task)
@@ -450,7 +441,7 @@ class BbTrackerJobs(TrackerJobsBase):
 
     @cached_property
     def movie_tags_job(self):
-        self.imdb_job.signal.register('output', self.fill_in_movie_tags)
+        self.imdb_job.signal.register('finished', self.fill_in_movie_tags)
         return jobs.dialog.TextFieldJob(
             name=self.get_job_name('movie-tags'),
             label='Tags',
@@ -462,12 +453,11 @@ class BbTrackerJobs(TrackerJobsBase):
     def movie_tags_validator(self, text):
         text = text.strip()
         if not text:
-            raise ValueError(f'Invalid tags: {text}')
+            raise ValueError('Failed to generate tags (use --tags)')
 
-    def fill_in_movie_tags(self, imdb_id):
-        coro = self.get_tags()
+    def fill_in_movie_tags(self, job_):
         task = self.movie_tags_job.fetch_text(
-            coro=coro,
+            coro=self.get_tags(),
             finish_on_success=True,
         )
         self.movie_tags_job.add_task(task)
@@ -485,13 +475,12 @@ class BbTrackerJobs(TrackerJobsBase):
 
     def movie_description_validator(self, text):
         text = text.strip()
-        if not text:
-            raise ValueError(f'Invalid description: {text}')
+        if not text or text == self.promotion:
+            raise ValueError('Failed to generate description (use --description)')
 
-    def fill_in_movie_description(self, _):
-        coro = self.get_description()
+    def fill_in_movie_description(self, job_):
         task = self.movie_description_job.fetch_text(
-            coro=coro,
+            coro=self.get_description(),
             finish_on_success=True,
         )
         self.movie_description_job.add_task(task)
@@ -501,16 +490,18 @@ class BbTrackerJobs(TrackerJobsBase):
     @cached_property
     def tvmaze_job(self):
         """:class:`~.jobs.webdb.WebDbSearchJob` instance"""
-        return jobs.webdb.WebDbSearchJob(
-            condition=self.make_job_condition('tvmaze_job', release.ReleaseType.season, release.ReleaseType.episode),
-            query=self.content_path,
-            db=self.tvmaze,
-            **self.common_job_args,
+        tvmaze_job = super().tvmaze_job
+        tvmaze_job.condition = self.make_job_condition(
+            'tvmaze_job',
+            release.ReleaseType.season,
+            release.ReleaseType.episode,
         )
+        tvmaze_job.no_id_ok = True
+        return tvmaze_job
 
     @cached_property
     def series_title_job(self):
-        self.tvmaze_job.signal.register('output', self.fill_in_series_title)
+        self.tvmaze_job.signal.register('finished', self.fill_in_series_title)
         return jobs.dialog.TextFieldJob(
             name=self.get_job_name('series-title'),
             label='Title',
@@ -522,17 +513,15 @@ class BbTrackerJobs(TrackerJobsBase):
     def series_title_validator(self, text):
         text = text.strip()
         if not text:
-            raise ValueError(f'Invalid title: {text}')
+            raise ValueError('Failed to generate title')
         unknown = ', '.join(u.lower() for u in re.findall(r'UNKNOWN_([A-Z_]+)', text))
         if unknown:
             raise ValueError(f'Failed to autodetect: {unknown}')
 
-    def fill_in_series_title(self, tvmaze_id):
-        coro = self.get_series_title_and_release_info(tvmaze_id)
-        default_text = self.release_name.title_with_aka_and_year
+    def fill_in_series_title(self, job_):
         task = self.series_title_job.fetch_text(
-            coro=coro,
-            default_text=default_text,
+            coro=self.get_series_title_and_release_info(),
+            default_text=self.release_name.title_with_aka_and_year,
             finish_on_success=False,
         )
         self.series_title_job.add_task(task)
@@ -554,7 +543,7 @@ class BbTrackerJobs(TrackerJobsBase):
 
     @cached_property
     def series_tags_job(self):
-        self.tvmaze_job.signal.register('output', self.fill_in_series_tags)
+        self.tvmaze_job.signal.register('finished', self.fill_in_series_tags)
         return jobs.dialog.TextFieldJob(
             name=self.get_job_name('series-tags'),
             label='Tags',
@@ -566,12 +555,11 @@ class BbTrackerJobs(TrackerJobsBase):
     def series_tags_validator(self, text):
         text = text.strip()
         if not text:
-            raise ValueError(f'Invalid tags: {text}')
+            raise ValueError('Failed to generate tags (use --tags)')
 
-    def fill_in_series_tags(self, tvmaze_id):
-        coro = self.get_tags()
+    def fill_in_series_tags(self, job_):
         task = self.series_tags_job.fetch_text(
-            coro=coro,
+            coro=self.get_tags(),
             finish_on_success=True,
         )
         self.series_tags_job.add_task(task)
@@ -589,13 +577,12 @@ class BbTrackerJobs(TrackerJobsBase):
 
     def series_description_validator(self, text):
         text = text.strip()
-        if not text:
-            raise ValueError(f'Invalid description: {text}')
+        if not text or text == self.promotion:
+            raise ValueError('Failed to generate description (use --description)')
 
-    def fill_in_series_description(self, _):
-        coro = self.get_description()
+    def fill_in_series_description(self, job_):
         task = self.series_description_job.fetch_text(
-            coro=coro,
+            coro=self.get_description(),
             finish_on_success=True,
         )
         self.series_description_job.add_task(task)
@@ -707,11 +694,14 @@ class BbTrackerJobs(TrackerJobsBase):
 
     @property
     def release_info_remastered(self):
-        for name in fs.file_and_parent(self.content_path):
-            if re.search(r'[ \.](?i:4k[ \.]remaster)', name):
-                return '4k Remaster'
-            elif re.search(r'[ \.](?i:remaster(ed|))[ \.]', name):
-                return 'Remastered'
+        if '4k Remastered' in self.release_name.edition:
+            return '4k Remaster'
+        elif '4k Restored' in self.release_name.edition:
+            return '4k Restored'
+        elif 'Remastered' in self.release_name.edition:
+            return 'Remastered'
+        elif 'Restored' in self.release_name.edition:
+            return 'Restored'
 
     @property
     def release_info_directors_cut(self):
@@ -758,16 +748,30 @@ class BbTrackerJobs(TrackerJobsBase):
         if 'Limited' in self.release_name.edition:
             return 'Limited'
 
+    @property
+    def release_info_2in1(self):
+        print(self.release_name.edition)
+        if '2in1' in self.release_name.edition:
+            return '2in1'
+
     # Metadata generators
 
-    async def get_movie_title(self, imdb_id):
-        await self.release_name.fetch_info(imdb_id)
-        return self.release_name.title_with_aka
-
-    async def get_series_title_and_release_info(self, tvmaze_id):
-        imdb_id = await self.tvmaze.imdb_id(tvmaze_id)
+    async def get_movie_title(self):
+        imdb_id = await self.get_imdb_id()
         if imdb_id:
-            await self.release_name.fetch_info(imdb_id)
+            await self.release_name.fetch_info(imdb_id=imdb_id)
+            return self.release_name.title_with_aka
+
+    async def get_movie_year(self):
+        imdb_id = await self.get_imdb_id()
+        if imdb_id:
+            await self.release_name.fetch_info(imdb_id=imdb_id)
+            return self.release_name.year
+
+    async def get_series_title_and_release_info(self):
+        imdb_id = await self.get_imdb_id()
+        if imdb_id:
+            await self.release_name.fetch_info(imdb_id=imdb_id)
 
         title = [self.release_name.title_with_aka]
         if self.release_name.year_required:
@@ -811,6 +815,7 @@ class BbTrackerJobs(TrackerJobsBase):
             self.release_info_criterion_edition,
             self.release_info_special_edition,
             self.release_info_limited_edition,
+            self.release_info_2in1,
 
             # Features
             self.release_info_dual_audio,
@@ -823,11 +828,15 @@ class BbTrackerJobs(TrackerJobsBase):
     async def get_resized_poster_url(self, poster_job, poster_url_getter):
         poster_path = await self.get_poster_file(poster_job, poster_url_getter)
         if not poster_path:
-            self.error('Provide a poster file or URL with the --poster-file option.')
+            self.error('Provide a poster file or URL with the --poster option.')
         else:
             # Resize poster
             try:
-                resized_poster_path = image.resize(poster_path, width=300)
+                resized_poster_path = image.resize(
+                    image_file=poster_path,
+                    target_directory=poster_job.home_directory,
+                    width=300,
+                )
             except errors.ImageResizeError as e:
                 self.error(f'Poster resizing failed: {e}')
             else:
@@ -842,20 +851,20 @@ class BbTrackerJobs(TrackerJobsBase):
                     poster_job.info = ''
 
     async def get_poster_file(self, poster_job, poster_url_getter):
-        if self.options.get('poster_file'):
-            # Get poster from CLI argument
-            if re.search(r'^[a-z]+://', self.options['poster_file']):
-                # CLI argument is URL
-                poster_url = self.options['poster_file']
+        if self.options.get('poster'):
+            # Get custom poster from user (e.g. CLI argument)
+            if re.search(r'^[a-z]+://', self.options['poster']):
+                # Poster argument is URL
+                poster_url = self.options['poster']
             else:
-                # CLI argument is file path
-                return self.options['poster_file']
+                # Poster is file path
+                return self.options['poster']
         else:
-            # Get poster URL from webdb (e.g. "https://imdb.com/...jpg")
+            # Get poster URL from webdb
             poster_url = await poster_url_getter()
 
         if not poster_url:
-            self.error('Failed to find poster URL.')
+            self.error('Failed to find poster URL (use --poster)')
         else:
             # Download poster
             poster_job.info = f'Downloading poster: {poster_url}'
@@ -906,6 +915,7 @@ class BbTrackerJobs(TrackerJobsBase):
             self.release_info_criterion_edition,
             self.release_info_special_edition,
             self.release_info_limited_edition,
+            self.release_info_2in1,
 
             # Features
             self.release_info_dual_audio,
@@ -915,86 +925,137 @@ class BbTrackerJobs(TrackerJobsBase):
         return ' / '.join(i for i in info if i)
 
     async def get_tags(self):
-        def normalize_tags(strings):
-            normalized = []
-            for s in strings:
-                s = (
-                    s
-                    .lower()
-                    .replace(' ', '.')
-                    .replace('-', '.')
-                    .replace('\'', '.')
-                )
-                s = re.sub(r'\.+', '.', s)  # Dedup "."
-                s = unidecode.unidecode(s)  # Replace non-ASCII
-                for regex, replacement in self._tags_translation.items():
-                    if regex.search(s):
-                        s = replacement
-                        break
-                normalized.append(s)
-            return normalized
+        if self.options.get('tags', ()):
+            # Get custom tags from user (e.g. CLI argument)
+            tags_list = self.options['tags'].split(',')
 
-        def assemble(*sequences):
-            return ','.join(
-                item
-                for seq in sequences
-                for item in seq
-            )
+        else:
+            # Get custom tags from webdb
 
-        # For movies, TVmaze ID is None and tvmaze is ignored.
-        # For series, IMDb might have information TVmaze is missing.
-        webdbs = (self.tvmaze, self.imdb)
+            # For movies, TVmaze ID is None and tvmaze is ignored.
+            # For series, IMDb might have information TVmaze is missing.
+            webdbs = (self.tvmaze, self.imdb)
 
-        # Gather tags
-        tags = list(await self.try_webdbs(webdbs, 'genres'))
-        if self.is_movie_release:
-            tags.extend(await self.try_webdbs(webdbs, 'directors'))
-        elif self.is_series_release:
-            tags.extend(await self.try_webdbs(webdbs, 'creators'))
-        tags.extend(await self.try_webdbs(webdbs, 'cast'))
+            # Gather tags
+            tags_list = list(await self.try_webdbs(webdbs, 'genres', default=()))
+            if self.is_movie_release:
+                tags_list.extend(await self.try_webdbs(webdbs, 'directors', default=()))
+            elif self.is_series_release:
+                tags_list.extend(await self.try_webdbs(webdbs, 'creators', default=()))
+            tags_list.extend(await self.try_webdbs(webdbs, 'cast', default=()))
 
-        # Replace spaces, non-ASCII characters, etc
-        tags = normalize_tags(tags)
-
-        # Maximum length of concatenated tags is 200 characters
-        tags_string = assemble(tags)
-        while len(tags_string) > 200:
-            del tags[-1]
-            tags_string = assemble(tags)
-
-        return tags_string
+        return self.normalize_tags(tags_list)
 
     _tags_translation = {
         re.compile('^sci.?fi$'): 'science.fiction',
     }
 
-    async def get_description(self):
-        info_table = await asyncio.gather(
-            self.format_description_webdbs(),
-            self.format_description_year(),
-            self.format_description_status(),
-            self.format_description_countries(),
-            self.format_description_runtime(),
-            self.format_description_directors(),
-            self.format_description_creators(),
-            self.format_description_cast(),
+    def normalize_tags(self, tags):
+        allowed_characters = (
+            string.group('ascii_lowercase')
+            + string.group('digits')
+            + '.'
         )
-        info_table_string = '\n'.join(str(item) for item in info_table
-                                      if item is not None)
-        parts = [
-            await self.format_description_summary() or '',
-            f'[quote]{info_table_string}[/quote]',
-        ]
 
-        if self.is_series_release:
-            parts.append(await self.format_description_series_screenshots())
-            parts.append(await self.format_description_series_mediainfo())
+        # Replace spaces, non-ASCII characters, etc
+        normalized = []
+        for tag in tags:
+            tag = (
+                str(tag)
+                .strip()
+                .lower()
+                .replace(' ', '.')
+                .replace('-', '.')
+                .replace("'", '')
+            )
+            tag = re.sub(r'\.+', '.', tag)  # Dedup "."
+            tag = unidecode.unidecode(tag)  # Translate exotic characters to ASCII
+            tag = ''.join(c for c in tag    # Remove remaining non-ASCII characters
+                          if c in allowed_characters)
+            for regex, replacement in self._tags_translation.items():
+                if regex.search(tag):
+                    tag = replacement
+                    break
+            normalized.append(tag)
+
+        def join_tags(tags):
+            return ','.join(str(tag) for tag in tags if tag)
+
+        # Maximum length of concatenated tags is 200 characters
+        tags_string = join_tags(normalized)
+        while len(tags_string) > 200:
+            del normalized[-1]
+            tags_string = join_tags(normalized)
+
+        return tags_string
+
+    async def get_description(self):
+        parts = []
+
+        if self.options.get('description', ''):
+            # Custom description
+            if os.path.exists(self.options['description']):
+                try:
+                    with open(self.options['description'], mode='r', encoding='utf-8') as f:
+                        parts.append(f.read())
+                except OSError as e:
+                    msg = e.strerror if e.strerror else str(e)
+                    self.error(f'Failed to read {self.options["description"]}: {msg}')
+                    return ''
+            else:
+                parts.append(self.options['description'])
+
+        else:
+            async def extend_parts(*coros, sep='', fmt='{text}'):
+                info_table = await asyncio.gather(*coros)
+                text = sep.join(
+                    str(item) for item in info_table
+                    if item is not None
+                )
+                if text:
+                    parts.append(fmt.format(text=text))
+
+            # Summary
+            await extend_parts(self.format_description_summary())
+
+            # Table-like quote block with details
+            await extend_parts(
+                self.format_description_webdbs(),
+                self.format_description_year(),
+                self.format_description_status(),
+                self.format_description_countries(),
+                self.format_description_runtime(),
+                self.format_description_directors(),
+                self.format_description_creators(),
+                self.format_description_cast(),
+                sep='\n',
+                fmt='[quote]{text}[/quote]',
+            )
+
+            # Series also have screenshots and mediainfo in their description
+            if self.is_series_release:
+                await extend_parts(
+                    self.format_description_series_screenshots(),
+                    self.format_description_series_mediainfo(),
+                )
+
+        # The promotion must be below. A closing [/quote] tags automatically
+        # appends a newline when rendered. Otherwise, append a newline
+        # character.
+        if parts and not parts[-1].endswith(('[/quote]', '\n')):
+            parts.append('\n')
 
         parts.append(self.promotion)
-        return ''.join(parts)
+        return ''.join(parts).strip()
+
+    promotion = (
+        '[align=right][size=1]Shared with '
+        f'[url={__homepage__}]{__project_name__} {__version__}[/url]'
+        '[/size][/align]'
+    )
 
     async def format_description_summary(self):
-        summary = await self.try_webdbs((self.tvmaze, self.imdb), 'summary')
+        summary = await self.try_webdbs((self.tvmaze, self.imdb), 'summary', default='')
         if summary:
             summary = '[quote]' + summary
             if self.is_episode_release and self.season and self.episode:
@@ -1082,7 +1143,7 @@ class BbTrackerJobs(TrackerJobsBase):
                 return f'[b]Status[/b]: {status}'
 
     async def format_description_countries(self):
-        countries = await self.try_webdbs((self.tvmaze, self.imdb), 'countries')
+        countries = await self.try_webdbs((self.tvmaze, self.imdb), 'countries', default=())
         if countries:
             return (f'[b]Countr{"ies" if len(countries) > 1 else "y"}[/b]: '
                     + ', '.join(countries))
@@ -1099,7 +1160,7 @@ class BbTrackerJobs(TrackerJobsBase):
             else:
                 return f'{minutes}m'
 
-        runtimes = await self.try_webdbs((self.imdb, self.tvmaze), 'runtimes')
+        runtimes = await self.try_webdbs((self.imdb, self.tvmaze), 'runtimes', default=())
         if len(runtimes) == 1:
             runtime = tuple(runtimes.values())[0]
             return f'[b]Runtime[/b]: {format_runtime(runtime)}'
@@ -1120,14 +1181,14 @@ class BbTrackerJobs(TrackerJobsBase):
             return str(person)
 
     async def format_description_directors(self):
-        directors = await self.try_webdbs((self.imdb, self.tvmaze), 'directors')
+        directors = await self.try_webdbs((self.imdb, self.tvmaze), 'directors', default=())
         if directors:
             directors_links = [self._format_person(director) for director in directors]
             return (f'[b]Director{"s" if len(directors) > 1 else ""}[/b]: '
                     + ', '.join(directors_links))
 
     async def format_description_creators(self):
-        creators = await self.try_webdbs((self.tvmaze, self.imdb), 'creators')
+        creators = await self.try_webdbs((self.tvmaze, self.imdb), 'creators', default=())
         if creators:
             creators_links = [self._format_person(creator) for creator in creators]
             return (f'[b]Creator{"s" if len(creators) > 1 else ""}[/b]: '
