@@ -47,7 +47,6 @@ class BbTracker(TrackerBase):
             )
 
             doc = html.parse('')
-            _log.debug('LOGINBUGDEBUG: Initial doc: %r', doc)
             while await self._work_around_login_bug(doc):
                 _log.debug('%s: Logging in as %r', self.name, self.options['username'])
                 response = await http.post(
@@ -59,9 +58,7 @@ class BbTracker(TrackerBase):
                         'login': 'Log In!',
                     },
                 )
-                _log.debug('LOGINBUGDEBUG: Login response: %r', response)
                 doc = html.parse(response)
-                _log.debug('LOGINBUGDEBUG: New doc %r', doc)
                 self._raise_login_error(doc)
 
             self._store_auth_token(doc)
@@ -102,22 +99,11 @@ class BbTracker(TrackerBase):
     def _get_auth_token(cls, doc):
         logout_link_tag = doc.find('a', href=cls._auth_token_regex)
         if logout_link_tag:
-            _log.debug('LOGINBUGDEBUG: logout_link_tag: %r', logout_link_tag)
             logout_link_href = logout_link_tag['href']
-            _log.debug('LOGINBUGDEBUG: logout_link_href: %r', logout_link_href)
             if logout_link_href:
                 match = cls._auth_token_regex.search(logout_link_href)
-                _log.debug('LOGINBUGDEBUG: logout_link_href match: %r', match)
                 if match:
-                    _log.debug('LOGINBUGDEBUG: auth_token: %r', match.group(1))
                     return match.group(1)
-                else:
-                    _log.debug('LOGINBUGDEBUG: Failed to find auth token: %r does not match %r',
-                               logout_link_href, cls._auth_token_regex)
-            else:
-                _log.debug('LOGINBUGDEBUG: Failed to find logout URL in HTML: %r', logout_link_tag)
-        else:
-            _log.debug('LOGINBUGDEBUG: Failed to find logout link tag in HTML: %r', doc)
 
     def _store_auth_token(self, doc):
         auth_token = self._get_auth_token(doc)
