@@ -27,6 +27,21 @@ class BhdTrackerConfig(TrackerConfigBase):
 
     argument_definitions = {
         'submit': {
+            ('--custom-edition', '--ce'): {
+                'help': 'Non-standard edition, e.g. "Final Cut"',
+                'default': '',
+            },
+            ('--draft', '--dr'): {
+                'help': 'Upload as draft',
+                'action': 'store_true',
+                # The default value must be None so CommandBase.get_options()
+                # doesn't always overwrite the value with the config file value.
+                'default': None,
+            },
+            ('--personal-rip', '--pr'): {
+                'help': 'Tag as your own encode',
+                'action': 'store_true',
+            },
             ('--screenshots', '--ss'): {
                 'help': ('How many screenshots to make '
                          f'(min={defaults["screenshots"].min}, '
@@ -36,32 +51,17 @@ class BhdTrackerConfig(TrackerConfigBase):
                     max=defaults['screenshots'].max,
                 ),
             },
-            ('--custom-edition', '-e'): {
-                'help': 'Non-standard edition, e.g. "Final Cut"',
-                'default': '',
-            },
-            ('--draft', '-d'): {
-                'help': 'Upload as draft',
-                'action': 'store_true',
-                # The default value must be None so CommandBase.get_options()
-                # doesn't always overwrite the value with the config file value.
-                'default': None,
-            },
-            ('--personal-rip', '-p'): {
-                'help': 'Tag as your own encode',
-                'action': 'store_true',
-            },
-            ('--special', '-s'): {
+            ('--special', '--sp'): {
                 'help': 'Tag as special episode, e.g. Christmas special (ignored for movie uploads)',
                 'action': 'store_true',
             },
-            ('--title', '-t'): {
-                'help': 'Only generate title (do not upload anything)',
+            ('--only-description', '--od'): {
+                'help': 'Only generate description (do not upload anything)',
                 'action': 'store_true',
                 'group': 'generate-metadata',
             },
-            ('--description', '--desc'): {
-                'help': 'Only generate description (do not upload anything)',
+            ('--only-title', '--oti'): {
+                'help': 'Only generate title (do not upload anything)',
                 'action': 'store_true',
                 'group': 'generate-metadata',
             },
