@@ -16,40 +16,43 @@ class submit(CommandBase):
     subcommand_name = 'TRACKER'
     subcommands = {
         tracker.name: {
-            # Default arguments for all tackers
-            **{
-                'CONTENT': {
-                    'type': utils.argtypes.content,
-                    'help': 'Path to release content',
-                },
-                ('--exclude-files', '--ef'): {
-                    'nargs': '+',
-                    'metavar': 'PATTERN',
-                    'help': ('Glob pattern to exclude from torrent '
-                             '(matched case-sensitively against path in torrent)'),
-                    'default': (),
-                },
-                ('--exclude-files-regex', '--efr'): {
-                    'nargs': '+',
-                    'metavar': 'PATTERN',
-                    'help': ('Regular expression to exclude from torrent '
-                             '(matched case-sensitively against path in torrent)'),
-                    'type': utils.argtypes.regex,
-                    'default': (),
-                },
-                ('--add-to', '-a'): {
-                    'type': utils.argtypes.client,
-                    'metavar': 'CLIENT',
-                    'help': ('Case-insensitive BitTorrent client name\n'
-                             'Supported clients: ' + ', '.join(utils.btclients.client_names())),
-                },
-                ('--copy-to', '-c'): {
-                    'metavar': 'PATH',
-                    'help': 'Copy the created torrent to PATH (file or directory)',
+            'description': f'Generate all required metadata and upload it to {tracker.label}.',
+            'cli': {
+                # Default arguments for all tackers
+                **{
+                    'CONTENT': {
+                        'type': utils.argtypes.content,
+                        'help': 'Path to release content',
+                    },
+                    ('--exclude-files', '--ef'): {
+                        'nargs': '+',
+                        'metavar': 'PATTERN',
+                        'help': ('Glob pattern to exclude from torrent '
+                                 '(matched case-sensitively against path in torrent)'),
+                        'default': (),
+                    },
+                    ('--exclude-files-regex', '--efr'): {
+                        'nargs': '+',
+                        'metavar': 'PATTERN',
+                        'help': ('Regular expression to exclude from torrent '
+                                 '(matched case-sensitively against path in torrent)'),
+                        'type': utils.argtypes.regex,
+                        'default': (),
+                    },
+                    ('--add-to', '-a'): {
+                        'type': utils.argtypes.client,
+                        'metavar': 'CLIENT',
+                        'help': ('Case-insensitive BitTorrent client name\n'
+                                 'Supported clients: ' + ', '.join(utils.btclients.client_names())),
+                    },
+                    ('--copy-to', '-c'): {
+                        'metavar': 'PATH',
+                        'help': 'Copy the created torrent to PATH (file or directory)',
+                    },
                 },
+                # Custom arguments defined by tracker for this command
+                **tracker.TrackerConfig.argument_definitions.get('submit', {}),
             },
-            # Custom arguments defined by tracker for this command
-            **tracker.TrackerConfig.argument_definitions.get('submit', {}),
         }
         for tracker in trackers.trackers()
     }
