@@ -4,6 +4,7 @@ Swiss Army knife
 
 import asyncio
 import collections
+import hashlib
 import importlib
 import inspect
 import itertools
@@ -356,6 +357,28 @@ def is_regex_pattern(object):
         return isinstance(object, typing.Pattern)
 
 
+def semantic_hash(obj):
+    """
+    Return SHA256 hash for `obj` that stays the same between Python interpreter
+    sessions
+
+    https://github.com/schollii/sandals/blob/master/json_sem_hash.py
+    """
+    def as_str(obj):
+        if isinstance(obj, collections.abc.Mapping):
+            sorted_keys = sorted(as_str(k) for k in obj.keys())
+            return {as_str(k): as_str(obj[k]) for k in sorted_keys}
+        elif isinstance(obj, str):
+            return str(obj)
+        elif isinstance(obj, collections.abc.Sequence):
+            sorted_items = sorted(as_str(i) for i in obj)
+            return [as_str(val) for val in sorted_items]
+        else:
+            return str(obj)
+
+    return hashlib.sha256(bytes(repr(as_str(obj)), 'UTF-8')).hexdigest()
+
+
 from . import (argtypes, browser, btclients, configfiles, daemon, fs, html,
                http, image, imghosts, iso, release, scene, signal, string,
                subproc, timestamp, torrent, types, update, video, webdbs)
