@@ -24,7 +24,7 @@ def _any2string(value):
     return ' '.join(str(v) for v in value) if _is_list(value) else str(value)
 
 
-class ConfigFiles:
+class ConfigFiles(collections.abc.MutableMapping):
     """
     Combine multiple INI-style configuration files into nested dictionaries
 
@@ -83,29 +83,18 @@ class ConfigFiles:
     @utils.cached_property
     def paths(self):
         """Sorted tuple of ``section.subsection.option`` paths"""
+
         def _get_paths(dct, parents=()):
             paths = []
             for k, v in dct.items():
                 k_parents = parents + (k,)
-                if isinstance(v, dict):
+                if isinstance(v, collections.abc.Mapping):
                     paths.extend(_get_paths(v, parents=k_parents))
                 else:
                     paths.append('.'.join(str(k) for k in k_parents))
             return tuple(sorted(paths))
-        return _get_paths(self._defaults)
 
-    def _set(self, section, subsection, option, value):
-        if section not in self._cfg:
-            raise errors.ConfigError(f'{section}: Unknown section')
-        elif subsection not in self._cfg[section]:
-            raise errors.ConfigError(f'{section}.{subsection}: Unknown subsection')
-        elif option not in self._cfg[section][subsection]:
-            raise errors.ConfigError(f'{section}.{subsection}.{option}: Unknown option')
-        else:
-            try:
-                self._cfg[section][subsection][option] = value
-            except errors.ConfigError as e:
-                raise errors.ConfigError(f'{section}.{subsection}.{option}: {e}')
+        return _get_paths(self._defaults)
 
     def read(self, section, filepath, ignore_missing=False):
         """
@@ -131,6 +120,19 @@ class ConfigFiles:
                             raise errors.ConfigError(f'{filepath}: {e}')
                 self._files[section] = filepath
 
+    def _set(self, section, subsection, option, value):
+        if section not in self._cfg:
+            raise errors.ConfigError(f'{section}: Unknown section')
+        elif subsection not in self._cfg[section]:
+            raise errors.ConfigError(f'{section}.{subsection}: Unknown subsection')
+        elif option not in self._cfg[section][subsection]:
+            raise errors.ConfigError(f'{section}.{subsection}.{option}: Unknown option')
+        else:
+            try:
+                self._cfg[section][subsection][option] = value
+            except errors.ConfigError as e:
+                raise errors.ConfigError(f'{section}.{subsection}.{option}: {e}')
+
     @staticmethod
     def _parse(section, string, filepath):
         cfg = configparser.ConfigParser(
@@ -186,9 +188,22 @@ class ConfigFiles:
             target = self._cfg
         target[key] = value
 
+    def __delitem__(self, key):
+        self.reset(key)
+
     def __iter__(self):
         return iter(self._cfg)
 
+    def __len__(self):
+        return len(self._cfg)
+
+    def __repr__(self):
+        return repr(self._cfg)
+
+    def copy(self):
+        """Return deep copy as :class:`dict`"""
+        return copy.deepcopy(self)
+
     def reset(self, path=()):
         """
         Set section, subsection or option to default value(s)
@@ -264,13 +279,8 @@ class ConfigFiles:
 
         return '\n'.join(lines)
 
-    def __repr__(self):
-        return repr(self._cfg)
 
-
-# Inherit from MutableMapping to get the ABC benefits. Inherit from dict so that
-# `isinstance(spec_dict_instance, dict)` returns True.
-class _ConfigDict(collections.abc.MutableMapping, dict):
+class _ConfigDict(collections.abc.MutableMapping):
     """
     Dictionary that only accepts certain keys and value types
 
@@ -360,3 +370,7 @@ class _ConfigDict(collections.abc.MutableMapping, dict):
 
     def __repr__(self):
         return repr(self._dct)
+
+    def copy(self):
+        """Return deep copy as :class:`dict`"""
+        return copy.deepcopy(self)
