@@ -12,13 +12,15 @@ class PreDbApi(base.SceneDbApiBase):
     name = 'predb'
     label = 'PreDB'
 
+    default_config = {}
+
     _url_base = b64decode('cHJlZGIub3Zo').decode('ascii')
     _search_url = f'https://{_url_base}/api/v1/'
 
     async def _search(self, keywords, group):
         if group:
             keywords = list(keywords)
-            keywords.extend(('@team', str(group)))
+            keywords.extend(('@team', str(group).replace('@', r'\@')))
         params = {'q': ' '.join((kw.lower() for kw in keywords)), 'count': 1000}
         _log.debug('Scene search: %r, %r', self._search_url, params)
 
