@@ -10,28 +10,28 @@ import os
 import time
 from os.path import exists as _path_exists
 
-from .. import __project_name__, __version__, errors
-from . import LazyModule, types
-
-import logging  # isort:skip
-_log = logging.getLogger(__name__)
+from .. import __project_name__, __version__, constants, errors, utils
+from . import LazyModule, fs, types
 
 torf = LazyModule(module='torf', namespace=globals())
 
 
-def create(*, content_path, announce, torrent_path,
+def create(*, content_path, announce, source, torrent_path,
            init_callback, progress_callback,
-           overwrite=False, source=None, exclude=()):
+           overwrite=False, exclude=()):
     """
     Generate and write torrent file
 
     :param str content_path: Path to the torrent's payload
     :param str announce: Announce URL
+    :param str source: Value of the ``source`` field in the torrent. This makes
+        the torrent unique for each tracker to avoid cross-seeding issues, so it
+        is usually the tracker's abbreviated name.
     :param str torrent_path: Path of the generated torrent file
     :param str init_callback: Callable that is called once before torrent
-        generation commences. It gets `content_path` as a tree where a node is a
-        tuple in which the first item is the directory name and the second item
-        is a sequence of `(file_name, file_size)` tuples.
+        generation commences. It gets `content_path` as a tree where each node
+        is a tuple in which the first item is the directory name and the second
+        item is a sequence of `(file_name, file_size)` tuples.
 
         Example:
 
@@ -57,8 +57,6 @@ def create(*, content_path, announce, torrent_path,
         Torrent creation is cancelled if `progress_callback` returns `True` or
         any other truthy value.
     :param bool overwrite: Whether to overwrite `torrent_path` if it exists
-    :param str source: Value of the "source" field in the torrent or `None` to
-        leave it out
     :param exclude: Sequence of regular expressions that are matched against
         file system paths. Matching files are not included in the torrent.
 
@@ -68,33 +66,122 @@ def create(*, content_path, announce, torrent_path,
     """
     if not announce:
         raise errors.TorrentError('Announce URL is empty')
+    if not source:
+        raise errors.TorrentError('Source is empty')
 
-    if not overwrite and _path_exists(torrent_path):
-        _log.debug('Torrent file already exists: %r', torrent_path)
-        return torrent_path
-    else:
-        callback = _CreateTorrentCallbackWrapper(progress_callback)
-        try:
-            torrent = torf.Torrent(
-                path=content_path,
-                exclude_regexs=exclude,
-                trackers=((announce,),),
-                private=True,
+    if overwrite or not _path_exists(torrent_path):
+        torrent = None
+
+        # Try to read piece hashes from cache
+        torrent = _read_cache_torrent(
+            content_path=content_path,
+            exclude=exclude,
+        )
+        if torrent:
+            # Update metadata in generic torrent
+            torrent.trackers = (announce,)
+            torrent.source = source
+        else:
+            # Reading cached piece hashes failed for some reason
+            torrent = _generate_torrent(
+                content_path=content_path,
+                announce=announce,
                 source=source,
-                created_by=f'{__project_name__} {__version__}',
-                creation_date=time.time(),
+                exclude=exclude,
+                progress_callback=progress_callback,
+                init_callback=init_callback,
             )
-            init_callback(_make_file_tree(torrent.filetree))
-            torrent.generate(callback=callback, interval=1.0)
+            if torrent.is_ready:
+                _store_cache_torrent(torrent)
+
+        # Write torrent file
+        try:
+            torrent.write(torrent_path, overwrite=True)
         except torf.TorfError as e:
             raise errors.TorrentError(e)
-        else:
-            try:
-                torrent.write(torrent_path, overwrite=overwrite)
-            except torf.TorfError as e:
-                raise errors.TorrentError(e)
-            else:
-                return torrent_path
+
+    return torrent_path
+
+
+def _generate_torrent(*, content_path, announce, source, exclude, init_callback, progress_callback):
+    callback = _CreateTorrentCallbackWrapper(progress_callback)
+    try:
+        torrent = torf.Torrent(
+            path=content_path,
+            exclude_regexs=exclude,
+            trackers=((announce,),),
+            private=True,
+            source=source,
+            created_by=f'{__project_name__} {__version__}',
+            creation_date=time.time(),
+        )
+        init_callback(_make_file_tree(torrent.filetree))
+        torrent.generate(callback=callback, interval=1.0)
+    except torf.TorfError as e:
+        raise errors.TorrentError(e)
+    else:
+        return torrent
+
+
+def _store_cache_torrent(torrent):
+    cache_torrent = torf.Torrent(
+        private=True,
+        created_by=f'{__project_name__} {__version__}',
+        creation_date=time.time(),
+        comment='This torrent is used to cache previously hashed pieces.',
+    )
+    _copy_torrent_info(torrent, cache_torrent)
+    cache_torrent_path = _get_cache_torrent_path(cache_torrent, create_directory=True)
+    cache_torrent.write(cache_torrent_path)
+
+
+def _read_cache_torrent(content_path, exclude):
+    try:
+        torrent = torf.Torrent(
+            path=content_path,
+            exclude_regexs=exclude,
+            private=True,
+            created_by=f'{__project_name__} {__version__}',
+            creation_date=time.time(),
+        )
+        cache_torrent_path = _get_cache_torrent_path(torrent, create_directory=False)
+        cache_torrent = torf.Torrent.read(cache_torrent_path)
+    except torf.TorfError:
+        return None
+    else:
+        _copy_torrent_info(cache_torrent, torrent)
+        return torrent
+
+
+def _get_cache_torrent_path(torrent, create_directory=True):
+    directory = os.path.join(
+        constants.CACHE_DIRPATH,
+        'generic_torrents',
+    )
+    if create_directory:
+        try:
+            fs.mkdir(directory)
+        except errors.ContentError as e:
+            raise errors.TorrentError(f'{directory}: {e}')
+
+    cache_id = {
+        'files': [(str(f), f.size) for f in torrent.files],
+        'piece_size': torrent.piece_size,
+    }
+    cache_id_string = utils.semantic_hash(cache_id)
+    filename = f'{torrent.name}.{cache_id_string}.torrent'
+    return os.path.join(directory, filename)
+
+
+def _copy_torrent_info(from_torrent, to_torrent):
+    from_info, to_info = from_torrent.metainfo['info'], to_torrent.metainfo['info']
+    to_info['pieces'] = from_info['pieces']
+    to_info['piece length'] = from_info['piece length']
+    to_info['name'] = from_info['name']
+    if 'length' in from_info:
+        to_info['length'] = from_info['length']
+    else:
+        to_info['files'] = from_info['files']
 
 
 def _make_file_tree(tree):
@@ -401,7 +488,7 @@ class TorrentFileStream:
                 return None
 
             # It's theoretically possible that a differntly sized file can
-            # produce the correct piece, b ut we assume the file is not what
+            # produce the correct piece, but we assume the file is not what
             # we're looking for if it doesn't have the expected size.
             elif f.size != self._get_file_size_from_fs(f):
                 return None
@@ -432,8 +519,9 @@ class TorrentFileStream:
         if os.path.exists(filepath):
             try:
                 return os.path.getsize(filepath)
-            except OSError as e:
-                _log.debug('Ignoring OSError: %r', e)
+            except OSError:
+                # Return None instead of raising an exception
+                pass
 
     def _get_open_file(self, file):
         filepath = os.path.join(self._location, file)
